import 'isomorphic-fetch';
declare global {
    interface Window {
        __kersplunkSingleton?: Logger;
    }
}
export declare type SplunkMeta = {
    time?: number;
    host?: string;
    source?: string;
    sourcetype?: string;
    index?: string;
};
export declare type SplunkMetaFactory = () => SplunkMeta;
export declare type LogInterceptor = (originalDetails: undefined | object) => undefined | object;
export declare type CustomLogger<TLogTypes extends string[]> = Logger & Record<TLogTypes[number] extends never ? (typeof DEFAULT_LOG_TYPES)[number] : TLogTypes[number], (eventName: string, details?: object) => void>;
declare type CoreLoggerConfiguration = {
    splunkUrl: string;
    authToken: string;
    maxBuffer: number;
    throttleDuration: number;
    splunkMeta?: SplunkMeta | SplunkMetaFactory;
    interceptor?: LogInterceptor;
    autoRetry: boolean;
    autoRetryDuration: number;
    enabled: boolean;
    logToConsole: boolean;
};
declare const DEFAULT_CONFIG: {
    maxBuffer: number;
    throttleDuration: number;
    autoRetry: boolean;
    autoRetryDuration: number;
    enabled: boolean;
    logToConsole: boolean;
};
declare const DEFAULT_LOG_TYPES: ("error" | "debug" | "info" | "warn")[];
export declare type LoggerConfiguration = Partial<Pick<CoreLoggerConfiguration, keyof typeof DEFAULT_CONFIG>> & Pick<CoreLoggerConfiguration, Exclude<keyof CoreLoggerConfiguration, keyof typeof DEFAULT_CONFIG>>;
export declare class Logger {
    static singleton<TLogTypes extends string[]>(config: LoggerConfiguration, ...logTypes: TLogTypes): CustomLogger<TLogTypes>;
    static create<TLogTypes extends string[]>(config: LoggerConfiguration, ...logTypes: TLogTypes): CustomLogger<TLogTypes>;
    static clearSingleton(): void;
    interceptor?: LogInterceptor;
    private _config;
    private _buffer;
    private _bufferTimeout?;
    private constructor();
    enable(): void;
    disable(): void;
    flush(): Promise<void>;
    private _log;
    private _flushBodyWithRetry;
    private _startOrResetBufferTimeout;
    private _clearBufferTimeout;
}
export {};
